# Parking management app
requires 
- python >= 3.6 installed on desktop
- pip  

**Install or upgrade**

`pip install parking-app --upgrade`

**Authenticate**

Before first run, you must authenticate.
From command line

`mpipes auth authenticate --micropipes_url https://devel3.parking.oid.digital`

and follow instructions. 
You can issue this command multiple times if you wish to work with multiple users 
(type different user credentials in web browser). 
With this feature you can then work/switch multiple authentications in parking-app.

**Run**

`parking-app`

**Run with debug informations**

`parking-app-debug`